yakumo.cinder.v2.service.Manager

Package yakumo :: Package cinder :: Package v2 :: Module service :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for services in Block Storage API v2

Nested Classes | [hide private]
| resource_class Resource class for services in Block Storage API v2

Instance Methods | [hide private]
None |
enable(self, host=None, binary=None) Enable a service on a host | source code
None |
disable(self, host=None, binary=None) Disable a service on a host | source code
None |
set_disabled_reason(self, host=None, binary=None, reason=None) Set disabled reason for a service on a host | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``]``
| _json_resource_key = ``'``service``'``
| _json_resources_key = ``'``services``'``
| _url_resource_path = ``'``/os-services``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### enable(self, host=None, binary=None) | source code
Enable a service on a host Parameters: `host` (str) - host name (required) `binary` (str) - binary name (required) Returns: None

### disable(self, host=None, binary=None) | source code
Disable a service on a host Parameters: `host` (str) - host name (required) `binary` (str) - binary name (required) Returns: None

### set_disabled_reason(self, host=None, binary=None, reason=None) | source code
Set disabled reason for a service on a host Parameters: `host` (str) - host name (required) `binary` (str) - binary name (required) `reason` (str) - description (required) Returns: None

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('host', 'host', mapper.Noop), ('binary',
      'binary', mapper.Noop), ('state', 'state', mapper.Noop), ('status', 's
      tatus', mapper.Noop), ('updated_at', 'updated_at', mapper.DateTime), (
      'availability_zone', 'zone', mapper.Resource('nova.availability_zone')
      ), ('disabled_reason', 'disabled_reason', mapper.Noop),]